#!/usr/bin/env python

import pymongo
import os
import argparse
from math import ceil

from lib import utils


def get_page_index(collection, page_size: int):
    page_index = []
    for i in range(0,  ceil(collection.count() / page_size)):
        page_index.append(get_tweets_page(collection, page_size, i))
    return page_index


def get_tweets_page(collection, page_size: int, num_page: int):
    tweets = collection.find().skip(num_page * page_size).limit(page_size)
    return tweets


if __name__ == "__main__":

    # Command line parsing
    parser = argparse.ArgumentParser(
        description="Dump the tweets of a database to a JSON file")
    parser.add_argument("-H", "--host", type=str, default="localhost")
    parser.add_argument("-p", "--port", type=int, default=27017)
    parser.add_argument("-s", "--pagesize", type=int, default=1000)
    parser.add_argument("database", type=str)
    args = parser.parse_args()

    # Dirs and files
    script_dir = os.path.dirname(__file__)
    output_dir = os.path.join(script_dir, "pymongodump", args.database)
    header_file = os.path.join(script_dir, "header.txt")

    # MongoDB connection
    client = pymongo.MongoClient(args.host, args.port)
    database_tweets = client[args.database]["tweets"]

    with open(header_file) as f:
        header = f.readline()
    buffer_tweets = {}
    num_page = 0

    page_index = get_page_index(database_tweets, args.pagesize)
    for page in page_index:
        buffer_tweets = {}
        for tweet in page:
            # Get output path and contents for the new CSV file
            csv_tweet_output_path =\
                utils.create_tweet_output_path(header, tweet, output_dir)
            csv_tweet_contents =\
                "\n" + str(utils.convert_tweet_to_csv(header, tweet))

            # Check if buffer exists for the file. If not, add to dictionary
            if csv_tweet_output_path not in buffer_tweets.keys():
                buffer_tweets[csv_tweet_output_path] = ["", 0]

            # Update the buffer adding the tweet and increasing tweet count
            buffer_tweets[csv_tweet_output_path][0] += csv_tweet_contents
            buffer_tweets[csv_tweet_output_path][1] += 1

        # Perform the write operations in each of the files
        for output_path in buffer_tweets.keys():
            with open(output_path, "a") as tweet_writer:
                tweet_writer.write(buffer_tweets[output_path][0])
                utils.increase_metadata_count(
                    os.path.join(output_dir, ".metadata.json"),
                    output_path, increase=buffer_tweets[output_path][1])
