import os
import json


def create_task_database_structure(
        output_dir: str,
        db_name: str)\
        -> str:
    """
    Generate the following directory tree: a top dir that will contain
    all the tweet collections if it didn't exist yet and within it the top
    directory for this task with a new and empty metadata file
    """

    # Create the root directory for the tweet collection
    if not os.path.isdir(output_dir):
        print(
            "Building directory to contain the collected tweets at: "
            + os.path.abspath(output_dir)
        )
        os.mkdir(output_dir)
    collection_path = os.path.join(output_dir, db_name)
    if not os.path.isdir(collection_path):
        print("Initializing collection " + db_name + "...")
        os.mkdir(collection_path)
        generate_metadata_file(collection_path)

    return collection_path


def generate_metadata_file(collection_path) -> None:
        print("Executing generate_metadata_file")
        metadata_path = os.path.join(collection_path, ".metadata.json")
        file_metadata = {}  # type: Dict
        metadata = {}
        metadata["files"] = file_metadata

        with open(metadata_path, "w") as f:
            json.dump(metadata, f)
